@@ -1,22 +1,20 @@
-/***************************************************************************
-    copyright            : (C) 2002 by Daniel Molkentin
-    email                : molkentin@kde.org
-
-    copyright            : (C) 2002 - 2004 by Scott Wheeler
-    email                : wheeler@kde.org
-
-    copyright            : (C) 2007, 2008, 2009 by Michael Pyne
-    email                : mpyne@kde.org
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+/**
+ * Copyright (C) 2002 Daniel Molkentin <molkentin@kde.org>
+ * Copyright (C) 2002-2004 Scott Wheeler <wheeler@kde.org>
+ * Copyright (C) 2007, 2008, 2009 Michael Pyne <mpyne@kde.org>
+ *
+ * This program is free software; you can redistribute it and/or modify it under
+ * the terms of the GNU General Public License as published by the Free Software
+ * Foundation; either version 2 of the License, or (at your option) any later
+ * version.
+ *
+ * This program is distributed in the hope that it will be useful, but WITHOUT ANY
+ * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
+ * PARTICULAR PURPOSE. See the GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License along with
+ * this program.  If not, see <http://www.gnu.org/licenses/>.
+ */
 
 #ifndef JUK_SYSTEMTRAY_H
 #define JUK_SYSTEMTRAY_H
